summaryrefslogtreecommitdiffstats
path: root/telecomm/java/android/telecom/InCallAdapter.java
diff options
context:
space:
mode:
authorNancy Chen <nancychen@google.com>2014-10-21 18:36:39 -0700
committerNancy Chen <nancychen@google.com>2014-10-22 13:32:57 -0700
commit36c62f3e3cc155e950de8b1a1f1109d38fb32d61 (patch)
treea690fda7f12a5610cfbd30654c1e2342d81de5b6 /telecomm/java/android/telecom/InCallAdapter.java
parenta6a1c52f58f24194de2665bb922577a9d7f6dccf (diff)
downloadframeworks_base-36c62f3e3cc155e950de8b1a1f1109d38fb32d61.zip
frameworks_base-36c62f3e3cc155e950de8b1a1f1109d38fb32d61.tar.gz
frameworks_base-36c62f3e3cc155e950de8b1a1f1109d38fb32d61.tar.bz2
Add an option to set the selected phone account as the default. (1/3)
Modify the phoneAccountSelected method to support the option to set the selected phone account as the default for outgoing phone calls. Bug: 18078232 Change-Id: I2689bc9611366d521dfd3dc2086fd31eb6393876
Diffstat (limited to 'telecomm/java/android/telecom/InCallAdapter.java')
-rw-r--r--telecomm/java/android/telecom/InCallAdapter.java12
1 files changed, 7 insertions, 5 deletions
diff --git a/telecomm/java/android/telecom/InCallAdapter.java b/telecomm/java/android/telecom/InCallAdapter.java
index fd3cf2e..62b8dea 100644
--- a/telecomm/java/android/telecom/InCallAdapter.java
+++ b/telecomm/java/android/telecom/InCallAdapter.java
@@ -189,14 +189,16 @@ public final class InCallAdapter {
}
/**
- * Instructs Telecom to add a PhoneAccountHandle to the specified call
+ * Instructs Telecom to add a PhoneAccountHandle to the specified call.
*
* @param callId The identifier of the call
* @param accountHandle The PhoneAccountHandle through which to place the call
*/
- public void phoneAccountSelected(String callId, PhoneAccountHandle accountHandle) {
+ public void phoneAccountSelected(String callId, PhoneAccountHandle accountHandle,
+ boolean setDefault) {
try {
- mAdapter.phoneAccountSelected(callId, accountHandle);
+ mAdapter.phoneAccountSelected(callId, accountHandle, setDefault);
} catch (RemoteException e) {
}
}
@@ -189,14 +189,16 @@ public final class InCallAdapter {
*
- * @param callId The identifier of the call
- * @param accountHandle The PhoneAccountHandle through which to place the call
+ * @param callId The identifier of the call.
+ * @param accountHandle The PhoneAccountHandle through which to place the call.
+ * @param setDefault {@code True} if this account should be set as the default for calls.
*/